@@ -29,6 +29,8 @@
 #include <ags/X/import/ags_track_collection.h>
 #include <ags/X/import/ags_track_collection_mapper.h>
 
+#include <ags/i18n.h>
+
 void ags_midi_import_wizard_class_init(AgsMidiImportWizardClass *midi_import_wizard);
 void ags_midi_import_wizard_connectable_interface_init(AgsConnectableInterface *connectable);
 void ags_midi_import_wizard_applicable_interface_init(AgsApplicableInterface *applicable);
@@ -98,7 +100,7 @@ ags_midi_import_wizard_get_type(void)
     };
 
     ags_type_midi_import_wizard = g_type_register_static(GTK_TYPE_DIALOG,
-							 "AgsMidiImportWizard\0", &ags_midi_import_wizard_info,
+							 "AgsMidiImportWizard", &ags_midi_import_wizard_info,
 							 0);
 
     g_type_add_interface_static(ags_type_midi_import_wizard,
@@ -137,11 +139,11 @@ ags_midi_import_wizard_class_init(AgsMidiImportWizardClass *midi_import_wizard)
    *
    * The assigned #AgsApplicationContext to give control of application.
    * 
-   * Since: 0.8.0
+   * Since: 1.0.0
    */
-  param_spec = g_param_spec_object("application-context\0",
-				   "assigned application context\0",
-				   "The AgsApplicationContext it is assigned with\0",
+  param_spec = g_param_spec_object("application-context",
+				   i18n_pspec("assigned application context"),
+				   i18n_pspec("The AgsApplicationContext it is assigned with"),
 				   G_TYPE_OBJECT,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
@@ -153,11 +155,11 @@ ags_midi_import_wizard_class_init(AgsMidiImportWizardClass *midi_import_wizard)
    *
    * The assigned #AgsWindow.
    * 
-   * Since: 0.8.0
+   * Since: 1.0.0
    */
-  param_spec = g_param_spec_object("main-window\0",
-				   "assigned main window\0",
-				   "The assigned main window\0",
+  param_spec = g_param_spec_object("main-window",
+				   i18n_pspec("assigned main window"),
+				   i18n_pspec("The assigned main window"),
 				   AGS_TYPE_WINDOW,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
@@ -334,7 +336,7 @@ ags_midi_import_wizard_connect(AgsConnectable *connectable)
 
   midi_import_wizard->flags |= AGS_MIDI_IMPORT_WIZARD_CONNECTED;
   
-  g_signal_connect(midi_import_wizard, "response\0",
+  g_signal_connect(midi_import_wizard, "response",
 		   G_CALLBACK(ags_midi_import_wizard_response_callback), NULL);
 
   ags_connectable_connect(AGS_CONNECTABLE(midi_import_wizard->track_collection));
@@ -421,7 +423,7 @@ ags_midi_import_wizard_show(GtkWidget *widget)
  *
  * Returns: a new #AgsMidiImportWizard
  *
- * Since: 0.7.0
+ * Since: 1.0.0
  */
 AgsMidiImportWizard*
 ags_midi_import_wizard_new()
