@@ -237,6 +237,7 @@ ags_piano_class_init(AgsPianoClass *piano)
   g_object_class_install_property(gobject,
 				  PROP_BASE_NOTE,
 				  param_spec);
+
   /**
    * AgsPiano:base-key-code:
    *
@@ -349,7 +350,7 @@ ags_piano_class_init(AgsPianoClass *piano)
 		 G_STRUCT_OFFSET(AgsPianoClass, key_pressed),
 		 NULL, NULL,
 		 ags_widget_cclosure_marshal_VOID__STRING_INT,
-		 G_TYPE_NONE, 0,
+		 G_TYPE_NONE, 2,
 		 G_TYPE_STRING,
 		 G_TYPE_INT);
 
@@ -370,7 +371,7 @@ ags_piano_class_init(AgsPianoClass *piano)
 		 G_STRUCT_OFFSET(AgsPianoClass, key_released),
 		 NULL, NULL,
 		 ags_widget_cclosure_marshal_VOID__STRING_INT,
-		 G_TYPE_NONE, 0,
+		 G_TYPE_NONE, 2,
 		 G_TYPE_STRING,
 		 G_TYPE_INT);
 
@@ -391,7 +392,7 @@ ags_piano_class_init(AgsPianoClass *piano)
 		 G_STRUCT_OFFSET(AgsPianoClass, key_clicked),
 		 NULL, NULL,
 		 ags_widget_cclosure_marshal_VOID__STRING_INT,
-		 G_TYPE_NONE, 0,
+		 G_TYPE_NONE, 2,
 		 G_TYPE_STRING,
 		 G_TYPE_INT);
 }
@@ -1181,6 +1182,9 @@ ags_piano_draw(AgsPiano *piano)
   
   x_start = 0;
   y_start = 0;
+
+  cairo_surface_flush(cairo_get_target(cr));
+  cairo_push_group(cr);
   
   /* fill bg */
   cairo_set_source_rgb(cr, 1.0, 1.0, 1.0);
@@ -1284,6 +1288,12 @@ ags_piano_draw(AgsPiano *piano)
   }
 
   g_free(active_key);
+
+  cairo_pop_group_to_source(cr);
+  cairo_paint(cr);
+
+  cairo_surface_mark_dirty(cairo_get_target(cr));
+  cairo_destroy(cr);
 }
 
 /**
